@@ -1,13 +1,15 @@
 from ._getter import FEATURES
 from ._getter import get_feature
+from .container import FeatureList
+from .container import ModuleOutput
 from .features import Barrier
 from .features import Empty
 from .features import ExpiryTime
 from .features import LogMoneyness
 from .features import MaxLogMoneyness
 from .features import MaxMoneyness
-from .features import ModuleOutput
 from .features import Moneyness
 from .features import PrevHedge
+from .features import TimeToMaturity
 from .features import Volatility
 from .features import Zeros
