@@ -5,14 +5,15 @@ from torch import Tensor
 
 from pfhedge._utils.doc import set_attr_and_docstring
 from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.str import _format_float
+from pfhedge.nn.functional import american_binary_payoff
 
-from ...nn.functional import american_binary_payoff
 from ..primary.base import Primary
+from .base import BaseOption
 from .base import Derivative
-from .base import OptionMixin
 
 
-class AmericanBinaryOption(Derivative, OptionMixin):
+class AmericanBinaryOption(BaseOption):
     """An American binary Option.
 
     An American binary call option pays an unit amount of cash if and only if
@@ -55,10 +56,10 @@ class AmericanBinaryOption(Derivative, OptionMixin):
         maturity (float, default=20/250): The maturity of the option.
         dtype (torch.device, optional): Desired device of returned tensor.
             Default: If None, uses a global default
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
         device (torch.device, optional): Desired device of returned tensor.
             Default: if None, uses the current device for the default tensor type
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and
             the current CUDA device for CUDA tensor types.
 
@@ -100,18 +101,17 @@ maturity=5/250, strike=1.01)
         self.maturity = maturity
         self.to(dtype=dtype, device=device)
 
-    def __repr__(self):
-        params = [f"{self.underlier.__class__.__name__}(...)"]
+    def extra_repr(self):
+        params = []
         if not self.call:
-            params.append(f"call={self.call}")
-        params.append(f"strike={self.strike}")
-        params.append(f"maturity={self.maturity:.2e}")
-        params += self.dinfo
-        return self.__class__.__name__ + "(" + ", ".join(params) + ")"
+            params.append("call=" + str(self.call))
+        params.append("strike=" + _format_float(self.strike))
+        params.append("maturity=" + _format_float(self.maturity))
+        return ", ".join(params)
 
     def payoff(self) -> Tensor:
         return american_binary_payoff(
-            self.underlier.spot, call=self.call, strike=self.strike
+            self.ul().spot, call=self.call, strike=self.strike
         )
 
 
@@ -119,9 +119,10 @@ maturity=5/250, strike=1.01)
 set_attr_and_docstring(AmericanBinaryOption, "simulate", Derivative.simulate)
 set_attr_and_docstring(AmericanBinaryOption, "to", Derivative.to)
 set_attr_and_docstring(AmericanBinaryOption, "ul", Derivative.ul)
+set_attr_and_docstring(AmericanBinaryOption, "list", Derivative.list)
 set_docstring(AmericanBinaryOption, "payoff", Derivative.payoff)
-set_attr_and_docstring(AmericanBinaryOption, "moneyness", OptionMixin.moneyness)
-set_attr_and_docstring(AmericanBinaryOption, "log_moneyness", OptionMixin.log_moneyness)
+set_attr_and_docstring(AmericanBinaryOption, "moneyness", BaseOption.moneyness)
+set_attr_and_docstring(AmericanBinaryOption, "log_moneyness", BaseOption.log_moneyness)
 set_attr_and_docstring(
-    AmericanBinaryOption, "time_to_maturity", OptionMixin.time_to_maturity
+    AmericanBinaryOption, "time_to_maturity", BaseOption.time_to_maturity
 )
