@@ -7,6 +7,7 @@ from torch import Tensor
 
 from pfhedge._utils.doc import set_attr_and_docstring
 from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.str import _format_float
 
 from ...stochastic import generate_heston
 from .base import Primary
@@ -28,20 +29,20 @@ class HestonStock(Primary):
         dt (float, default=1/250): The intervals of the time steps.
         dtype (torch.device, optional): Desired device of returned tensor.
             Default: If None, uses a global default
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
         device (torch.device, optional): Desired device of returned tensor.
             Default: if None, uses the current device for the default tensor type
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and
             the current CUDA device for CUDA tensor types.
 
     Buffers:
-        - ``spot`` (``torch.Tensor``): The spot price of the instrument.
+        - spot (:class:`torch.Tensor`): The spot price of the instrument.
           This attribute is set by a method :func:`simulate()`.
           The shape is :math:`(N, T)` where
           :math:`N` is the number of simulated paths and
           :math:`T` is the number of time steps.
-        - ``variance`` (``torch.Tensor``): The variance of the instrument.
+        - variance (:class:`torch.Tensor`): The variance of the instrument.
           Note that this is different from the realized variance of the spot price.
           This attribute is set by a method :func:`simulate()`.
           The shape is :math:`(N, T)`.
@@ -140,18 +141,17 @@ class HestonStock(Primary):
         self.register_buffer("spot", spot)
         self.register_buffer("variance", variance)
 
-    def __repr__(self) -> str:
+    def extra_repr(self) -> str:
         params = [
-            f"kappa={self.kappa:.2e}",
-            f"theta={self.theta:.2e}",
-            f"sigma={self.sigma:.2e}",
-            f"rho={self.rho:.2e}",
+            "kappa=" + _format_float(self.kappa),
+            "theta=" + _format_float(self.theta),
+            "sigma=" + _format_float(self.sigma),
+            "rho=" + _format_float(self.rho),
         ]
         if self.cost != 0.0:
-            params.append(f"cost={self.cost:.2e}")
-        params.append(f"dt={self.dt:.2e}")
-        params += self.dinfo
-        return self.__class__.__name__ + "(" + ", ".join(params) + ")"
+            params.append("cost=" + _format_float(self.cost))
+        params.append("dt=" + _format_float(self.dt))
+        return ", ".join(params)
 
 
 # Assign docstrings so they appear in Sphinx documentation
