@@ -297,3 +297,63 @@ def realized_volatility(input: Tensor, dt: Union[Tensor, float]) -> Tensor:
         torch.Tensor
     """
     return realized_variance(input, dt=dt).sqrt()
+
+
+def terminal_value(
+    spot: Tensor,
+    unit: Tensor,
+    cost: float = 0.0,
+    payoff: Optional[Tensor] = None,
+    deduct_first_cost: bool = True,
+):
+    """Returns the terminal portfolio value.
+
+    The terminal value of a hedger's portfolio is given by
+
+    .. math::
+
+        \\text{PL}(Z, \\delta, S) =
+        - Z
+        + \\sum_{i = 1}^{T - 1} \\delta_{i} (S_{i + 1} - S_i)
+        - c \\sum_{i = 1}^{T - 1} |\\delta_{i + 1} - \\delta_{i}| S_{i + 1}
+
+    where :math:`Z` is the payoff of the derivative, :math:`T` is the number of
+    time steps, :math:`S` is the spot price, :math:`\\delta` is the signed number
+    of shares held at each time step.
+
+    Args:
+        spot (torch.Tensor): The spot price of the underlying asset :math:`S`.
+        unit (torch.Tensor): The signed number of shares of the underlying asset
+            :math:`\\delta`.
+        cost (float, default=0.0): The proportional transaction cost rate of
+            the underlying asset :math:`c`.
+        payoff (torch.Tensor, optional): The payoff of the derivative :math:`Z`.
+        deduct_first_cost (bool, default=True): Whether to deduct the transaction
+            cost of transacting stocks at the first time step.
+            If ``True``, :math:`c |\delta_1| S_1` will be deducted from the above
+            equation of the terminal value.
+
+    Shape:
+        - spot: :math:`(*, T)` where :math:`T` is the number of time steps.
+        - unit: :math:`(*, T)`
+        - payoff: :math:`(*)`
+        - output: :math:`(*)`.
+
+    Returns:
+        torch.Tensor
+    """
+    if spot.size() != unit.size():
+        raise RuntimeError(f"unmatched sizes: spot {spot.size()}, unit {unit.size()}")
+    if payoff is not None and spot.size()[:-1] != payoff.size():
+        raise RuntimeError(
+            f"unmatched sizes: spot {spot.size()}, payoff {payoff.size()}"
+        )
+
+    value = unit[..., :-1].mul(spot.diff(dim=-1)).sum(-1)
+    value += -cost * unit.diff(dim=-1).abs().mul(spot[..., 1:]).sum(-1)
+    if payoff is not None:
+        value -= payoff
+    if deduct_first_cost:
+        value -= cost * unit[..., 0].abs() * spot[..., 0]
+
+    return value
