@@ -4,6 +4,7 @@ from torch import Tensor
 import pfhedge.autogreek as autogreek
 from pfhedge._utils.bisect import bisect
 from pfhedge._utils.doc import set_attr_and_docstring
+from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
 
@@ -35,7 +36,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         >>>
         >>> m = BSAmericanBinaryOption(strike=1.0)
         >>> m.inputs()
-        ['log_moneyness', 'max_log_moneyness', 'expiry_time', 'volatility']
+        ['log_moneyness', 'max_log_moneyness', 'time_to_maturity', 'volatility']
         >>> input = torch.tensor([
         ...     [-0.01, -0.01, 0.1, 0.2],
         ...     [ 0.00,  0.00, 0.1, 0.2],
@@ -79,21 +80,20 @@ class BSAmericanBinaryOption(BSModuleMixin):
             >>> derivative = AmericanBinaryOption(BrownianStock(), strike=1.1)
             >>> m = BSAmericanBinaryOption.from_derivative(derivative)
             >>> m
-            BSAmericanBinaryOption(strike=1.1)
+            BSAmericanBinaryOption(strike=1.1000)
         """
         return cls(call=derivative.call, strike=derivative.strike)
 
     def extra_repr(self) -> str:
         params = []
-        if self.strike != 1.0:
-            params.append(f"strike={self.strike}")
+        params.append("strike=" + _format_float(self.strike))
         return ", ".join(params)
 
     def price(
         self,
         log_moneyness: Tensor,
         max_log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         volatility: Tensor,
     ) -> Tensor:
         """Returns price of the derivative.
@@ -101,13 +101,13 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
             - max_log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -115,7 +115,8 @@ class BSAmericanBinaryOption(BSModuleMixin):
             Tensor
         """
         s, m, t, v = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, volatility)
+            torch.as_tensor,
+            (log_moneyness, max_log_moneyness, time_to_maturity, volatility),
         )
 
         sqrt2 = torch.tensor(2.0).sqrt().item()
@@ -130,7 +131,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         self,
         log_moneyness: Tensor,
         max_log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         volatility: Tensor,
     ) -> Tensor:
         """Returns delta of the derivative.
@@ -138,13 +139,13 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
             - max_log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -152,7 +153,8 @@ class BSAmericanBinaryOption(BSModuleMixin):
             torch.Tensor
         """
         s, m, t, v = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, volatility)
+            torch.as_tensor,
+            (log_moneyness, max_log_moneyness, time_to_maturity, volatility),
         )
 
         sqrt2 = torch.tensor(2.0).sqrt().item()
@@ -171,7 +173,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         self,
         log_moneyness: Tensor,
         max_log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         volatility: Tensor,
     ) -> Tensor:
         """Returns gamma of the derivative.
@@ -179,13 +181,13 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
 
         Shape:
             - log_moneyness: :math:`(N, *)`
             - max_log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -197,7 +199,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
             strike=self.strike,
             log_moneyness=log_moneyness,
             max_log_moneyness=max_log_moneyness,
-            expiry_time=expiry_time,
+            time_to_maturity=time_to_maturity,
             volatility=volatility,
         )
 
@@ -205,7 +207,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         self,
         log_moneyness: Tensor,
         max_log_moneyness: Tensor,
-        expiry_time: Tensor,
+        time_to_maturity: Tensor,
         price: Tensor,
         precision: float = 1e-6,
     ) -> Tensor:
@@ -214,7 +216,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Args:
             log_moneyness (torch.Tensor): Log moneyness of the underlying asset.
             max_log_moneyness (torch.Tensor): Cumulative maximum of the log moneyness.
-            expiry_time (torch.Tensor): Time to expiry of the option.
+            time_to_maturity (torch.Tensor): Time to expiry of the option.
             volatility (torch.Tensor): Volatility of the underlying asset.
             precision (float, default=1e-6): Computational precision of the implied
                 volatility.
@@ -222,7 +224,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
         Shape:
             - log_moneyness: :math:`(N, *)`
             - max_log_moneyness: :math:`(N, *)`
-            - expiry_time: :math:`(N, *)`
+            - time_to_maturity: :math:`(N, *)`
             - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
@@ -230,7 +232,7 @@ class BSAmericanBinaryOption(BSModuleMixin):
             torch.Tensor
         """
         s, m, t, p = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, expiry_time, price)
+            torch.as_tensor, (log_moneyness, max_log_moneyness, time_to_maturity, price)
         )
         pricer = lambda volatility: self.price(s, m, t, volatility)
         return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
