@@ -3,6 +3,8 @@ from typing import List
 from torch import Tensor
 from torch.nn import Module
 
+from pfhedge._utils.str import _format_float
+
 from .bs.black_scholes import BlackScholes
 from .clamp import Clamp
 
@@ -12,7 +14,26 @@ class WhalleyWilmott(Module):
 
     The ``forward`` method returns the next hedge ratio.
 
-    This is the optimal hedging strategy for asymptotically small transaction cost.
+    This is the no-transaction band strategy
+    that is optimal under the premises of
+    asymptotically small transaction cost, European option, and exponential utility.
+    The half-width of the no-transaction band is given by
+
+    .. math ::
+
+        w = \\left( \\frac{3 c \\Gamma^2 S}{2 a} \\right)^{1 / 3} \,,
+
+    where :math:`c` is the transaction cost rate, :math:`\\Gamma` is the gamma of
+    the derivative, :math:`S` is the spot price of the underlying instrument, and
+    :math:`a` is the risk-aversion coefficient of the exponential utility.
+
+    .. note ::
+
+        A backward computation for this module generates ``nan``
+        if the :math:`\\Gamma` of the derivative is too small.
+        This is because the output is proportional to :math:`\\Gamma^{2 / 3}`
+        of which gradient diverges for :math:`\\Gamma \\to 0`.
+        A ``dtype`` with higher precision may alleviate this problem.
 
     Args:
         derivative (:class:`pfhedge.instruments.Derivative`): Derivative to hedge.
@@ -37,7 +58,7 @@ class WhalleyWilmott(Module):
         >>>
         >>> m = WhalleyWilmott(derivative)
         >>> m.inputs()
-        ['log_moneyness', 'expiry_time', 'volatility', 'prev_hedge']
+        ['log_moneyness', 'time_to_maturity', 'volatility', 'prev_hedge']
         >>> input = torch.tensor([
         ...     [-0.05, 0.1, 0.2, 0.5],
         ...     [-0.01, 0.1, 0.2, 0.5],
@@ -56,7 +77,7 @@ class WhalleyWilmott(Module):
         >>> derivative = EuropeanOption(BrownianStock())
         >>> m = WhalleyWilmott(derivative)
         >>> m.inputs()
-        ['log_moneyness', 'expiry_time', 'volatility', 'prev_hedge']
+        ['log_moneyness', 'time_to_maturity', 'volatility', 'prev_hedge']
         >>> input = torch.tensor([
         ...     [-0.05, 0.1, 0.2, 0.5],
         ...     [-0.01, 0.1, 0.2, 0.5],
@@ -93,7 +114,7 @@ class WhalleyWilmott(Module):
         return self.bs.inputs() + ["prev_hedge"]
 
     def extra_repr(self) -> str:
-        return f"a={self.a}" if self.a != 1 else ""
+        return "a=" + _format_float(self.a) if self.a != 1 else ""
 
     def forward(self, input: Tensor) -> Tensor:
         prev_hedge = input[..., [-1]]
